# Contributing Guide

Please, for now, only contribute in the form of [feedback](https://github.com/hynek/svcs/discussions/1) and/or [issues](https://github.com/hynek/svcs/issues).

The project is not ready for code contributions yet.
Yes, I still use `git push --force` occasionally.
